@@ -1,5 +1,5 @@
 
-import six
+from .util import compat
 
 
 class DatabaseException(Exception):
@@ -10,8 +10,8 @@ class DatabaseException(Exception):
     def __str__(self):
         text = 'Orig exception: {}'.format(self.orig)
 
-        if six.PY3:
-            return six.text_type(text)
+        if compat.PY3:
+            return compat.text_type(text)
 
         else:
-            return six.text_type(text).encode('utf-8')
+            return compat.text_type(text).encode('utf-8')
